<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="nl">
<context>
    <name>MainWindow</name>
    <message>
        <source>MX Welcome</source>
        <translation type="vanished">MX Welkom</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="109"/>
        <source>&amp;Copy for forum</source>
        <translation>&amp;Copy voor forum</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="92"/>
        <source>Save the displayed system information to a text file.</source>
        <translation>Sla de weergegeven systeeminformatie op in een tekstbestand.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="95"/>
        <location filename="../mainwindow.cpp" line="85"/>
        <source>Save text...</source>
        <translation>Tekst opslaan...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="106"/>
        <source>Copy the displayed system information to the clipboard, encased in [CODE][/CODE] tags ready to use in a forum post.</source>
        <translation>Kopieer de weergegeven systeeminformatie naar het klembord, ingesloten in [CODE][/CODE] tags, klaar voor gebruik in een forumbericht.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="154"/>
        <source>Save the system information selected from the list to an archive file.</source>
        <translation>Sla de systeeminformatie uit de lijst op in een archiefbestand.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="157"/>
        <location filename="../mainwindow.cpp" line="107"/>
        <source>&amp;Save...</source>
        <translation>&amp;Opslaan...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="224"/>
        <source>Quit application</source>
        <translation>Verlaat de applicatie</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="227"/>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="234"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="270"/>
        <source>About this application</source>
        <translation>Over deze toepassing</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="273"/>
        <source>About...</source>
        <translation>Over...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="280"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="204"/>
        <source>Help</source>
        <translation>Hulp</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="155"/>
        <source>Version: </source>
        <translation>Versie:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="32"/>
        <location filename="../mainwindow.cpp" line="155"/>
        <location filename="../mainwindow.cpp" line="310"/>
        <source>Quick System Info</source>
        <translation>Snelle Systeeminformatie</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="55"/>
        <source>Loading...</source>
        <translation>Laden...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="159"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="154"/>
        <source>About Quick-System-Info-gui</source>
        <translation>Over Quick-Systeem-Info-gui</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="96"/>
        <source>Select &amp;All</source>
        <translation>Selecteer &amp;Alles</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="102"/>
        <source>Revert Selection</source>
        <translation>Selectie Terugdraaien</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="156"/>
        <source>Program for displaying a quick system info report</source>
        <translation>Programma voor het weergeven van een snel systeem informatie rapport</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="160"/>
        <source>License</source>
        <translation>Licentie</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="251"/>
        <source>Open folder</source>
        <translation>Open map</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="253"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="412"/>
        <source>&amp;Save (×%1)...</source>
        <translation>&amp;Opslaan (×%1)...</translation>
    </message>
    <message>
        <source>Changelog</source>
        <translation type="vanished">Changelog</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">Ongedaan maken</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="vanished">&amp;Sluiten</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="191"/>
        <source>Save System Information</source>
        <translation>Systeeminformatie Opslaan</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="250"/>
        <source>System information saved.</source>
        <translation>Systeeminformatie opgeslagen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="258"/>
        <source>Could not save system information.</source>
        <translation>Kon systeeminformatie niet opslaan.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="317"/>
        <source>history</source>
        <translation>geschiedenis</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="333"/>
        <source>%1 Help</source>
        <translation>%1 Help</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="333"/>
        <source>Quick System Info (gui)</source>
        <translation>Snelle Systeeminformatie (gui)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="75"/>
        <source>Copy for forum</source>
        <translation>Kopieer voor forum</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="80"/>
        <source>Plain text copy</source>
        <translation>Kopie in gewone tekst</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>You must run this program as normal user.</source>
        <translation>U moet dit programma als normale gebruiker uitvoeren.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="43"/>
        <source>This tool displays a the quick system info report in a gui.</source>
        <translation>Deze tool toont een snel systeem info rapport in een gui.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="40"/>
        <source>License</source>
        <translation>Licentie</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="41"/>
        <location filename="../about.cpp" line="51"/>
        <source>Changelog</source>
        <translation>Changelog</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <source>Cancel</source>
        <translation>Ongedaan maken</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="63"/>
        <source>&amp;Close</source>
        <translation>&amp;Sluiten</translation>
    </message>
</context>
</TS>